Skip to contents

This class represents a feature table (ft) object, which contains a table of ASVs and their sequences, along with optional clustering information and filtering parameters.

Arguments

table

A data frame containing the feature table with ASVs and sequences.

clusters

A data frame containing cluster assignments, populated by cluster_asv_table().

filter

A list containing filtering parameters applied to the table, populated by filter_asv_table().