Skip to contents

Obisidan callouts can be one of many types. If a header line is not given, then the header defaults to the name of the type. Text for an optional body can also be provided.

Usage

obs_callout(type = "info", header = "", body = "")

Arguments

type

The type of callout

header

text to put in the header line

body

text to put in the body