Obisidan callouts can be one of many types. If a header line is not given, then the header defaults to the name of the type. Text for an optional body can also be provided.
Obisidan callouts can be one of many types. If a header line is not given, then the header defaults to the name of the type. Text for an optional body can also be provided.